iamai.adapter.dingtalk package
==============================

Submodules
----------

.. toctree::
   :maxdepth: 4

   iamai.adapter.dingtalk.config
   iamai.adapter.dingtalk.event
   iamai.adapter.dingtalk.exceptions
   iamai.adapter.dingtalk.message

Module contents
---------------

.. automodule:: iamai.adapter.dingtalk
   :members:
   :undoc-members:
   :show-inheritance:
